==> Google-Ads-GoogleAds-Client-10.0.1.tar.gz: Google-Ads-GoogleAds-Client-10.0.1/lib/Google/Ads/GoogleAds/V10/Enums/LeadFormFieldUserInputTypeEnum.pm <==
# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V10::Enums::LeadFormFieldUserInputTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED                            => "UNSPECIFIED",
  UNKNOWN                                => "UNKNOWN",
  FULL_NAME                              => "FULL_NAME",
  EMAIL                                  => "EMAIL",
  PHONE_NUMBER                           => "PHONE_NUMBER",
  POSTAL_CODE                            => "POSTAL_CODE",
  CITY                                   => "CITY",
  REGION                                 => "REGION",
  COUNTRY                                => "COUNTRY",
  WORK_EMAIL                             => "WORK_EMAIL",
  COMPANY_NAME                           => "COMPANY_NAME",
  WORK_PHONE                             => "WORK_PHONE",
  JOB_TITLE                              => "JOB_TITLE",
  FIRST_NAME                             => "FIRST_NAME",
  LAST_NAME                              => "LAST_NAME",
  VEHICLE_MODEL                          => "VEHICLE_MODEL",
  VEHICLE_TYPE                           => "VEHICLE_TYPE",
  PREFERRED_DEALERSHIP                   => "PREFERRED_DEALERSHIP",
  VEHICLE_PURCHASE_TIMELINE              => "VEHICLE_PURCHASE_TIMELINE",
  VEHICLE_OWNERSHIP                      => "VEHICLE_OWNERSHIP",
  VEHICLE_PAYMENT_TYPE                   => "VEHICLE_PAYMENT_TYPE",
  VEHICLE_CONDITION                      => "VEHICLE_CONDITION",
  COMPANY_SIZE                           => "COMPANY_SIZE",
  ANNUAL_SALES                           => "ANNUAL_SALES",
  YEARS_IN_BUSINESS                      => "YEARS_IN_BUSINESS",
  JOB_DEPARTMENT                         => "JOB_DEPARTMENT",
  JOB_ROLE                               => "JOB_ROLE",
  EDUCATION_PROGRAM                      => "EDUCATION_PROGRAM",
  EDUCATION_COURSE                       => "EDUCATION_COURSE",
  PRODUCT                                => "PRODUCT",
  SERVICE                                => "SERVICE",
  OFFER                                  => "OFFER",
  CATEGORY                               => "CATEGORY",
  PREFERRED_CONTACT_METHOD               => "PREFERRED_CONTACT_METHOD",
  PREFERRED_LOCATION                     => "PREFERRED_LOCATION",
  PREFERRED_CONTACT_TIME                 => "PREFERRED_CONTACT_TIME",
  PURCHASE_TIMELINE                      => "PURCHASE_TIMELINE",
  YEARS_OF_EXPERIENCE                    => "YEARS_OF_EXPERIENCE",
  JOB_INDUSTRY                           => "JOB_INDUSTRY",
  LEVEL_OF_EDUCATION                     => "LEVEL_OF_EDUCATION",
  PROPERTY_TYPE                          => "PROPERTY_TYPE",
  REALTOR_HELP_GOAL                      => "REALTOR_HELP_GOAL",
  PROPERTY_COMMUNITY                     => "PROPERTY_COMMUNITY",
  PRICE_RANGE                            => "PRICE_RANGE",
  NUMBER_OF_BEDROOMS                     => "NUMBER_OF_BEDROOMS",
  FURNISHED_PROPERTY                     => "FURNISHED_PROPERTY",
  PETS_ALLOWED_PROPERTY                  => "PETS_ALLOWED_PROPERTY",
  NEXT_PLANNED_PURCHASE                  => "NEXT_PLANNED_PURCHASE",
  EVENT_SIGNUP_INTEREST                  => "EVENT_SIGNUP_INTEREST",
  PREFERRED_SHOPPING_PLACES              => "PREFERRED_SHOPPING_PLACES",
  FAVORITE_BRAND                         => "FAVORITE_BRAND",
  TRANSPORTATION_COMMERCIAL_LICENSE_TYPE =>
    "TRANSPORTATION_COMMERCIAL_LICENSE_TYPE",
  EVENT_BOOKING_INTEREST => "EVENT_BOOKING_INTEREST",
  DESTINATION_COUNTRY    => "DESTINATION_COUNTRY",
  DESTINATION_CITY       => "DESTINATION_CITY",
  DEPARTURE_COUNTRY      => "DEPARTURE_COUNTRY",
  DEPARTURE_CITY         => "DEPARTURE_CITY",
  DEPARTURE_DATE         => "DEPARTURE_DATE",
  RETURN_DATE            => "RETURN_DATE",
  NUMBER_OF_TRAVELERS    => "NUMBER_OF_TRAVELERS",
  TRAVEL_BUDGET          => "TRAVEL_BUDGET",
  TRAVEL_ACCOMMODATION   => "TRAVEL_ACCOMMODATION"
];

1;

==> Google-Ads-GoogleAds-Client-13.0.0.tar.gz: Google-Ads-GoogleAds-Client-13.0.0/lib/Google/Ads/GoogleAds/V10/Enums/LeadFormFieldUserInputTypeEnum.pm <==
# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V10::Enums::LeadFormFieldUserInputTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED                            => "UNSPECIFIED",
  UNKNOWN                                => "UNKNOWN",
  FULL_NAME                              => "FULL_NAME",
  EMAIL                                  => "EMAIL",
  PHONE_NUMBER                           => "PHONE_NUMBER",
  POSTAL_CODE                            => "POSTAL_CODE",
  CITY                                   => "CITY",
  REGION                                 => "REGION",
  COUNTRY                                => "COUNTRY",
  WORK_EMAIL                             => "WORK_EMAIL",
  COMPANY_NAME                           => "COMPANY_NAME",
  WORK_PHONE                             => "WORK_PHONE",
  JOB_TITLE                              => "JOB_TITLE",
  GOVERNMENT_ISSUED_ID_CPF_BR            => "GOVERNMENT_ISSUED_ID_CPF_BR",
  GOVERNMENT_ISSUED_ID_DNI_AR            => "GOVERNMENT_ISSUED_ID_DNI_AR",
  GOVERNMENT_ISSUED_ID_DNI_PE            => "GOVERNMENT_ISSUED_ID_DNI_PE",
  GOVERNMENT_ISSUED_ID_RUT_CL            => "GOVERNMENT_ISSUED_ID_RUT_CL",
  GOVERNMENT_ISSUED_ID_CC_CO             => "GOVERNMENT_ISSUED_ID_CC_CO",
  GOVERNMENT_ISSUED_ID_CI_EC             => "GOVERNMENT_ISSUED_ID_CI_EC",
  GOVERNMENT_ISSUED_ID_RFC_MX            => "GOVERNMENT_ISSUED_ID_RFC_MX",
  FIRST_NAME                             => "FIRST_NAME",
  LAST_NAME                              => "LAST_NAME",
  VEHICLE_MODEL                          => "VEHICLE_MODEL",
  VEHICLE_TYPE                           => "VEHICLE_TYPE",
  PREFERRED_DEALERSHIP                   => "PREFERRED_DEALERSHIP",
  VEHICLE_PURCHASE_TIMELINE              => "VEHICLE_PURCHASE_TIMELINE",
  VEHICLE_OWNERSHIP                      => "VEHICLE_OWNERSHIP",
  VEHICLE_PAYMENT_TYPE                   => "VEHICLE_PAYMENT_TYPE",
  VEHICLE_CONDITION                      => "VEHICLE_CONDITION",
  COMPANY_SIZE                           => "COMPANY_SIZE",
  ANNUAL_SALES                           => "ANNUAL_SALES",
  YEARS_IN_BUSINESS                      => "YEARS_IN_BUSINESS",
  JOB_DEPARTMENT                         => "JOB_DEPARTMENT",
  JOB_ROLE                               => "JOB_ROLE",
  EDUCATION_PROGRAM                      => "EDUCATION_PROGRAM",
  EDUCATION_COURSE                       => "EDUCATION_COURSE",
  PRODUCT                                => "PRODUCT",
  SERVICE                                => "SERVICE",
  OFFER                                  => "OFFER",
  CATEGORY                               => "CATEGORY",
  PREFERRED_CONTACT_METHOD               => "PREFERRED_CONTACT_METHOD",
  PREFERRED_LOCATION                     => "PREFERRED_LOCATION",
  PREFERRED_CONTACT_TIME                 => "PREFERRED_CONTACT_TIME",
  PURCHASE_TIMELINE                      => "PURCHASE_TIMELINE",
  YEARS_OF_EXPERIENCE                    => "YEARS_OF_EXPERIENCE",
  JOB_INDUSTRY                           => "JOB_INDUSTRY",
  LEVEL_OF_EDUCATION                     => "LEVEL_OF_EDUCATION",
  PROPERTY_TYPE                          => "PROPERTY_TYPE",
  REALTOR_HELP_GOAL                      => "REALTOR_HELP_GOAL",
  PROPERTY_COMMUNITY                     => "PROPERTY_COMMUNITY",
  PRICE_RANGE                            => "PRICE_RANGE",
  NUMBER_OF_BEDROOMS                     => "NUMBER_OF_BEDROOMS",
  FURNISHED_PROPERTY                     => "FURNISHED_PROPERTY",
  PETS_ALLOWED_PROPERTY                  => "PETS_ALLOWED_PROPERTY",
  NEXT_PLANNED_PURCHASE                  => "NEXT_PLANNED_PURCHASE",
  EVENT_SIGNUP_INTEREST                  => "EVENT_SIGNUP_INTEREST",
  PREFERRED_SHOPPING_PLACES              => "PREFERRED_SHOPPING_PLACES",
  FAVORITE_BRAND                         => "FAVORITE_BRAND",
  TRANSPORTATION_COMMERCIAL_LICENSE_TYPE =>
    "TRANSPORTATION_COMMERCIAL_LICENSE_TYPE",
  EVENT_BOOKING_INTEREST => "EVENT_BOOKING_INTEREST",
  DESTINATION_COUNTRY    => "DESTINATION_COUNTRY",
  DESTINATION_CITY       => "DESTINATION_CITY",
  DEPARTURE_COUNTRY      => "DEPARTURE_COUNTRY",
  DEPARTURE_CITY         => "DEPARTURE_CITY",
  DEPARTURE_DATE         => "DEPARTURE_DATE",
  RETURN_DATE            => "RETURN_DATE",
  NUMBER_OF_TRAVELERS    => "NUMBER_OF_TRAVELERS",
  TRAVEL_BUDGET          => "TRAVEL_BUDGET",
  TRAVEL_ACCOMMODATION   => "TRAVEL_ACCOMMODATION"
];

1;
